Search.setIndex({objects:{ttag:{Tag:[2,0,1]},"":{output:[2,1,1],render:[2,1,1]}},terms:{represent:2,all:[1,2],consum:2,follow:[0,2],compact:2,unpack:3,readabl:2,friendli:1,string:2,fals:[0,2],retriev:2,tagnam:2,relev:2,cool:2,level:2,list:[0,3],keywordsarg:[0,2],item:2,second:2,pass:[0,2],download:3,append:[0,2],compat:2,index:3,appear:2,datetimearg:2,neg:0,section:0,current:2,version:0,method:[0,2],whatev:0,full:[0,1],behavior:2,modelinstancearg:[0,2],let:0,modifi:[0,2],valu:[0,2],convert:2,datearg:2,datetim:2,chang:2,overrid:2,via:2,tweak:0,modul:3,prefer:[2,3],"boolean":2,tweaknam:0,instal:[1,3],getus:2,from:[0,2,3],describ:1,would:[0,2,3],regist:[0,2],two:[0,2],call:2,type:[0,1,2,3],until:[0,2],more:[0,2],trail:2,flag:2,templat:[0,1,2],uncool:2,easiest:3,must:[0,2],none:2,join:0,positionaltag:2,setup:3,work:0,obvious:[2,3],can:[0,2,3],purpos:1,def:[0,2],control:2,accept:[0,2],tag:[0,1,2],want:[0,2],occur:2,end:[0,2],rather:[0,2],measuretag:2,write:[0,1],"__init__":0,instead:0,simpl:[0,2],booleanarg:[0,2],after:[0,2],befor:3,attent:2,date:2,multipl:[0,2],data:[0,2],demonstr:0,conscious:0,greet:0,django:[0,1,2,3],caus:[0,2],allow:[0,2],order:2,templatetag:2,still:2,paramet:2,style:2,render:[0,2],easier:1,them:2,"return":[0,2],thei:2,python:3,integerarg:[0,2],now:0,name:[0,2],anyth:2,revers:0,separ:[0,2],token:[0,2],mode:2,found:0,unicod:2,compil:2,everyth:0,replac:2,meta:[0,2],our:0,variabl:2,space:[0,2],some_librari:2,profil:0,compile_valu:2,insid:2,advanc:0,manipul:2,standard:[0,2,3],base:[0,2],dictionari:[0,2],latest:3,releas:[1,3],could:2,as_:2,turn:2,confus:0,assign:2,first:2,directli:2,onc:3,mai:[0,2],done:0,installed_app:3,miss:2,fanci:0,given:2,isinstancearg:2,script:3,namedtag:2,messag:2,inner:[0,2],option:[0,2],tool:3,copi:3,took:[0,2],specifi:[0,2],tweak_nam:0,part:[2,3],pars:[0,2],consult:1,than:[0,2],keyword:[0,2],provid:[0,2],remov:2,zero:0,project:[1,3],posit:[0,2],sai:0,some_limit:0,ani:2,packag:3,have:[2,3],need:3,"null":2,built:2,self:[0,2],stringarg:2,mix:2,take:2,which:[0,1,2],noth:3,singl:2,even:2,clash:2,normal:2,object:2,templatetagvalidationerror:2,"class":[0,2],cover:1,doe:2,clean:[0,1,2],usual:[0,2],cooltag:2,verbos:2,syntax:1,onli:2,explicitli:[0,2],hadn:0,configur:[1,3],should:[0,2],variou:[0,2],get:[0,1],autom:3,constantarg:2,requir:[0,2,3],bar:2,whether:[0,2],thistag:2,contain:[0,2],where:0,clean_limit:0,altern:[0,2],set:[0,2,3],nodelist_empti:0,see:0,result:[0,2],arg:[0,2],extend:0,"import":0,attribut:0,end_block:[0,2],kei:0,filterexpress:2,addit:2,both:2,howev:3,equal:2,against:[0,2],instanc:[0,2],context:[0,1,2],modif:0,as_var:2,overview:[1,2],pop:0,timearg:2,settag:2,respect:0,guid:1,assum:2,empti:[0,2],mark:2,basic:0,resolut:2,argument:[0,1,2],"case":0,look:0,properti:2,alter:[0,1,2],defin:[0,1,2],abov:0,error:2,get_full_nam:0,sever:0,welcom:[0,2],minim:0,receiv:0,make:1,same:0,handl:[0,2],pai:2,document:1,finish:2,assist:[0,2],rais:[0,2],user:[0,2],expand:0,appropri:0,off:0,person:0,exampl:[0,1,2],thi:[0,1,2],choos:2,model:[0,1,2],basicarg:[0,2],left:2,nodelist:[0,2],just:[0,3],aspect:2,simpli:[2,3],note:0,except:2,param:2,add:[0,3],valid:[0,2],appli:0,els:2,subsequ:2,match:0,applic:1,format:[0,2],camelcas:2,bit:0,like:[0,3],arbitrari:0,manual:3,resolv:[0,2],integ:2,collect:0,benefit:0,necessari:1,either:[0,2],endrepeat:0,output:[0,2],some:0,librari:[0,1,2],advancedtag:0,definit:2,subclass:2,slash:2,foo:2,refer:[1,2],run:[1,3],usag:[0,1,2],step:1,offset:[0,2],"super":0,"throw":2,simpler:[0,2],obj:0,ttag:[0,1,2,3],slightli:0,constructor:[1,2],block:[0,1,2],tagvalidationerror:0,automat:[0,3],been:0,your:[0,1,2,3],wai:[0,2,3],custom:2,start:[0,2,3],includ:0,form:[0,1,2],cls_name:2,"true":[0,2],count:0,"default":[0,2],amazingstuff:2,below:2,limit:[0,2],otherwis:2,similar:2,namedmodel:0,creat:[0,1,2],templatesyntaxerror:0,parser:0,doesn:2,exist:2,pip:3,check:0,when:[0,2],field:[0,2],other:[0,2],test:3,you:[0,2,3],node:[0,2],under_scor:2,repeat:0,determin:2,amazing_stuff:2,time:2,push:0,backward:2},objtypes:{"0":"py:class","1":"py:method"},titles:["Usage","django-ttag","Reference","Installation"],objnames:{"0":"Python class","1":"Python method"},filenames:["usage","index","reference","install"]})